<?php

namespace Mageme\WebFormsProcessResult\Observer;

use Magento\Framework\Event\ObserverInterface;
use VladimirPopov\WebForms\Model;

class WebformsResultSaveObserver implements ObserverInterface
{
    /** @var \Magento\Store\Model\StoreManager */
    protected $_storeManager;

    /** @var \Psr\Log\LoggerInterface */
    protected $logger;

    /**
     * @var \Magento\Framework\Message\ManagerInterface
     */
    protected $messageManager;

    public function __construct(
        \Magento\Store\Model\StoreManager $storeManager,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Psr\Log\LoggerInterface $logger
    )
    {
        $this->_storeManager = $storeManager;
        $this->messageManager = $messageManager;
        $this->logger = $logger;
    }

    /**
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {

        /** @var Model\Form $webform */
        $webform = $observer->getWebform();

        /*
        *   Check web-form code
        *   if($webform->getCode() != 'myform') return $this;
        */

        /** @var Model\Result $result */
        $result = $observer->getResult();

        $xmlObject = new \Magento\Framework\Simplexml\Element($result->toXml());

        // generate unique filename
        $mediaFolder = $this->_storeManager->getStore($result->getStoreId())->getBaseMediaDir();
        $destinationFolder = $mediaFolder . '/' . 'webforms' . '/' . 'xml';
        $filename = $destinationFolder . '/' . $result->getId() . '.xml';

        // create folder
        if (!(@is_dir($destinationFolder) || @mkdir($destinationFolder, 0755, true))) {
            $this->messageManager->addErrorMessage("Unable to create directory '{$destinationFolder}'.");
        } else {

            // export to file
            $xmlObject->asNiceXml($filename);
        }
        return $this;
    }


}
